@@ -24,18 +24,15 @@
 
 #include "curl_setup.h"
 
-#include <curl/curl.h>
 #include "urldata.h"
 #include "connect.h"
 #include "curl_share.h"
-#include "psl.h"
 #include "vtls/vtls.h"
 #include "vtls/vtls_scache.h"
 #include "hsts.h"
 #include "url.h"
 
-CURLSH *
-curl_share_init(void)
+CURLSH *curl_share_init(void)
 {
   struct Curl_share *share = curlx_calloc(1, sizeof(struct Curl_share));
   if(share) {
@@ -60,8 +57,7 @@ curl_share_init(void)
 }
 
 #undef curl_share_setopt
-CURLSHcode
-curl_share_setopt(CURLSH *sh, CURLSHoption option, ...)
+CURLSHcode curl_share_setopt(CURLSH *sh, CURLSHoption option, ...)
 {
   va_list param;
   int type;
@@ -224,8 +220,7 @@ curl_share_setopt(CURLSH *sh, CURLSHoption option, ...)
   return res;
 }
 
-CURLSHcode
-curl_share_cleanup(CURLSH *sh)
+CURLSHcode curl_share_cleanup(CURLSH *sh)
 {
   struct Curl_share *share = sh;
   if(!GOOD_SHARE_HANDLE(share))
@@ -273,10 +268,8 @@ curl_share_cleanup(CURLSH *sh)
   return CURLSHE_OK;
 }
 
-
-CURLSHcode
-Curl_share_lock(struct Curl_easy *data, curl_lock_data type,
-                curl_lock_access accesstype)
+CURLSHcode Curl_share_lock(struct Curl_easy *data, curl_lock_data type,
+                           curl_lock_access accesstype)
 {
   struct Curl_share *share = data->share;
 
@@ -292,8 +285,7 @@ Curl_share_lock(struct Curl_easy *data, curl_lock_data type,
   return CURLSHE_OK;
 }
 
-CURLSHcode
-Curl_share_unlock(struct Curl_easy *data, curl_lock_data type)
+CURLSHcode Curl_share_unlock(struct Curl_easy *data, curl_lock_data type)
 {
   struct Curl_share *share = data->share;
 
@@ -302,7 +294,7 @@ Curl_share_unlock(struct Curl_easy *data, curl_lock_data type)
 
   if(share->specifier & (unsigned int)(1 << type)) {
     if(share->unlockfunc) /* only call this if set! */
-      share->unlockfunc (data, type, share->clientdata);
+      share->unlockfunc(data, type, share->clientdata);
   }
 
   return CURLSHE_OK;
