@@ -35,6 +35,7 @@
 #include "http2.h"
 #include "http.h"
 #include "sendf.h"
+#include "curl_trc.h"
 #include "select.h"
 #include "curlx/base64.h"
 #include "multiif.h"
@@ -43,12 +44,9 @@
 #include "urlapi-int.h"
 #include "cfilters.h"
 #include "connect.h"
-#include "rand.h"
-#include "curlx/strparse.h"
 #include "transfer.h"
 #include "bufref.h"
 #include "curlx/dynbuf.h"
-#include "curlx/warnless.h"
 #include "headers.h"
 
 #if (NGHTTP2_VERSION_NUM < 0x010c00)
